@@ -1,16 +1,19 @@
 """Cross-python stdlib shims."""
 
 import os
-import typing as t
+import sys
 from contextlib import contextmanager
 from pathlib import Path
+from typing import Iterator
 
-try:
-    from contextlib import chdir as chdir_cm  # type: ignore[attr-defined]
-except ImportError:
+if sys.version_info >= (3, 11):
+    from contextlib import chdir as chdir_cm
+    from tomllib import loads as load_toml_from_string
+else:
+    from tomli import loads as load_toml_from_string
 
     @contextmanager  # type: ignore[no-redef]
-    def chdir_cm(path: os.PathLike) -> t.Iterator[None]:
+    def chdir_cm(path: "os.PathLike[str]") -> Iterator[None]:
         """Temporarily change the current directory, recovering on exit."""
         original_wd = Path.cwd()
         os.chdir(path)
@@ -20,10 +23,4 @@ except ImportError:
             os.chdir(original_wd)
 
 
-try:
-    from tomllib import loads as load_toml_from_string
-except ImportError:
-    from tomli import loads as load_toml_from_string  # type: ignore[no-redef]
-
-
 __all__ = ("chdir_cm", "load_toml_from_string")  # noqa: WPS410
